# Ambio

A light-weight bioinformatics library written in Python. It contains a variety of algorithms and functions that deal with strings.

## Documentation

The complete documentation can be found on [ambio.readthedocs.io](https://ambio.readthedocs.io/)

## Installation

Run the following command in a terminal to install:

```bash
$ pip install ambio
```

## Development

To install `ambio`, along with the tools you need to develop and run tests, run the following command:

```bash
$ pip install -e .
```
